tlslite.constants.CipherSuite

Package tlslite :: Module constants :: Class CipherSuite |
[show private | hide private]
[frames | no frames]

## Class CipherSuite

Method Summary
| `getRsaSuites(ciphers)` (Static method)
| `getSrpRsaSuites(ciphers)` (Static method)
| `getSrpSuites(ciphers)` (Static method)

Class Variable Summary
`list` | `aes128Suites` = `[83, 84, 47]`
`list` | `aes256Suites` = `[86, 87, 53]`
`list` | `rc4Suites` = `[5]`
`list` | `rsaSuites` = `[10, 47, 53, 5]`
`list` | `srpRsaSuites` = `[81, 84, 87]`
`list` | `srpSuites` = `[80, 83, 86]`
`int` | `TLS_RSA_WITH_3DES_EDE_CBC_SHA` = 10
`int` | `TLS_RSA_WITH_AES_128_CBC_SHA` = 47
`int` | `TLS_RSA_WITH_AES_256_CBC_SHA` = 53
`int` | `TLS_RSA_WITH_RC4_128_SHA` = 5
`int` | `TLS_SRP_SHA_RSA_WITH_3DES_EDE_CBC_SHA` = 81
`int` | `TLS_SRP_SHA_RSA_WITH_AES_128_CBC_SHA` = 84
`int` | `TLS_SRP_SHA_RSA_WITH_AES_256_CBC_SHA` = 87
`int` | `TLS_SRP_SHA_WITH_3DES_EDE_CBC_SHA` = 80
`int` | `TLS_SRP_SHA_WITH_AES_128_CBC_SHA` = 83
`int` | `TLS_SRP_SHA_WITH_AES_256_CBC_SHA` = 86
`list` | `tripleDESSuites` = `[80, 81, 10]`

Class Variable Details

    ### aes128Suites Type: `list` Value:
        [83, 84, 47]

    ### aes256Suites Type: `list` Value:
        [86, 87, 53]

    ### rc4Suites Type: `list` Value:
        [5]

    ### rsaSuites Type: `list` Value:
        [10, 47, 53, 5]

    ### srpRsaSuites Type: `list` Value:
        [81, 84, 87]

    ### srpSuites Type: `list` Value:
        [80, 83, 86]

    ### TLS_RSA_WITH_3DES_EDE_CBC_SHA Type: `int` Value:
        10

    ### TLS_RSA_WITH_AES_128_CBC_SHA Type: `int` Value:
        47

    ### TLS_RSA_WITH_AES_256_CBC_SHA Type: `int` Value:
        53

    ### TLS_RSA_WITH_RC4_128_SHA Type: `int` Value:
        5

    ### TLS_SRP_SHA_RSA_WITH_3DES_EDE_CBC_SHA Type: `int` Value:
        81

    ### TLS_SRP_SHA_RSA_WITH_AES_128_CBC_SHA Type: `int` Value:
        84

    ### TLS_SRP_SHA_RSA_WITH_AES_256_CBC_SHA Type: `int` Value:
        87

    ### TLS_SRP_SHA_WITH_3DES_EDE_CBC_SHA Type: `int` Value:
        80

    ### TLS_SRP_SHA_WITH_AES_128_CBC_SHA Type: `int` Value:
        83

    ### TLS_SRP_SHA_WITH_AES_256_CBC_SHA Type: `int` Value:
        86

    ### tripleDESSuites Type: `list` Value:
        [80, 81, 10]

Generated by Epydoc 2.0 on Mon Feb 21 21:56:56 2005 | http://epydoc.sf.net